Skip to main content

gareth

Tool to manage the developer installation of GrimoireLab.

This software is licensed under GPL3 or later.

Requirements

  • Python >= 3.6
  • Poetry >= 1.0
  • Click >= 7.1.2
  • PyGithub >= 1.55
  • GitPython >= 3.1.15

Installation

Getting the source code

Clone the repository

$ git clone https://github.com/vchrombie/gareth/
$ cd gareth

Prerequisites

Poetry

We use Poetry for managing the project. You can install it following these steps.

We use Bitergia/release-tools for managing the releases.

Installation

Install the required dependencies (this will also create a virtual environment)

$ poetry install

Activate the virtual environment

$ poetry shell

Usage

Once you install the tool, you can use it with the gareth command.

$ gareth --help
Usage: gareth [OPTIONS]

  Tool to manage the developer installation of GrimoireLab.

Options:
  -t, --token TEXT   GitHub API Token.
  -s, --source TEXT  The source folder of the dev env.  [default: sources]
  --create           Create the developer setup.
  --update           Update the developer setup.
  --help             Show this message and exit.

Create the developer environment setup

$ gareth -t xxxx -s sources --create

Update the developer environment setup

$ gareth -s sources --update

Contributions

All the contributions are welcome. Please feel free to open an issue or a PR. If you are opening any PR for the code, please be sure to add a changelog entry.

License

Licensed under GNU General Public License (GPL), version 3 or later.

Metadata

Release files for gareth 0.1.0

For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.

Source distribution (sdist)

Source distribution for gareth 0.1.0
File Size Uploaded
gareth-0.1.0.tar.gz 16.9 kB Details

Built distribution (wheel)

Table of built distributions (wheels) for gareth 0.1.0
File Interpreter ABI Platform
gareth-0.1.0-py3-none-any.whl Python 3 none any Details

Total release size: 47.8 kB

Release files / gareth-0.1.0.tar.gz

Download URL gareth-0.1.0.tar.gz
Size 16.9 kB
Tags Source
SHA-256 checksum
How to use checksums
c69ee74bab1ae1c0ec8f5a1c9703413650cea28146ce097dc3977a2d71b78951
BLAKE2b-256 checksum
How to use checksums
9d25c307a48fdaa87f1d87f916d9b8b47ee6680eef1993873c58866d5baf3d4c
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via poetry/1.1.6 CPython/3.9.4 Linux/5.4.0-1046-azure

Release files / gareth-0.1.0-py3-none-any.whl

Download URL gareth-0.1.0-py3-none-any.whl
Size 30.9 kB
Tags Python 3
SHA-256 checksum
How to use checksums
c7a57cca5f2dfc1f2412cad9fee747890337787c03db8962b8e768b550b76516
BLAKE2b-256 checksum
How to use checksums
a160594b221a3832302e821cb4fd866ca0c93499199e901bb64178ba29956c71
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via poetry/1.1.6 CPython/3.9.4 Linux/5.4.0-1046-azure

Release history Release notifications | RSS feed

This release

0.1.0 This release

2 release files

Anthropic, PBC Visionary sponsor Bloomberg Visionary sponsor Hudson River Trading Visionary sponsor Meta Visionary sponsor NVIDIA Visionary sponsor Microsoft Sustainability sponsor Depot Continuous Integration AWS Cloud computing and Security Sponsor Datadog Monitoring Fastly CDN Google Download Analytics Sentry Error logging StatusPage Status page